@@ -109,11 +109,11 @@ final class PublishBatchInput extends Input
     {
         $payload = [];
         if (null === $v = $this->topicArn) {
-            throw new InvalidArgument(sprintf('Missing parameter "TopicArn" for "%s". The value cannot be null.', __CLASS__));
+            throw new InvalidArgument(\sprintf('Missing parameter "TopicArn" for "%s". The value cannot be null.', __CLASS__));
         }
         $payload['TopicArn'] = $v;
         if (null === $v = $this->publishBatchRequestEntries) {
-            throw new InvalidArgument(sprintf('Missing parameter "PublishBatchRequestEntries" for "%s". The value cannot be null.', __CLASS__));
+            throw new InvalidArgument(\sprintf('Missing parameter "PublishBatchRequestEntries" for "%s". The value cannot be null.', __CLASS__));
         }
 
         $index = 0;
