@@ -6,7 +6,6 @@ use AsyncAws\Core\AbstractApi;
 use AsyncAws\Core\AwsError\AwsErrorFactoryInterface;
 use AsyncAws\Core\AwsError\XmlAwsErrorFactory;
 use AsyncAws\Core\Configuration;
-use AsyncAws\Core\Exception\UnsupportedRegion;
 use AsyncAws\Core\RequestContext;
 use AsyncAws\Core\Result;
 use AsyncAws\Sns\Exception\AuthorizationErrorException;
@@ -365,28 +364,35 @@ class SnsClient extends AbstractApi
     }
 
     /**
-     * Publishes up to ten messages to the specified topic. This is a batch version of `Publish`. For FIFO topics, multiple
-     * messages within a single batch are published in the order they are sent, and messages are deduplicated within the
-     * batch and across batches for 5 minutes.
+     * Publishes up to 10 messages to the specified topic in a single batch. This is a batch version of the `Publish` API.
+     * If you try to send more than 10 messages in a single batch request, you will receive a `TooManyEntriesInBatchRequest`
+     * exception.
+     *
+     * For FIFO topics, multiple messages within a single batch are published in the order they are sent, and messages are
+     * deduplicated within the batch and across batches for five minutes.
      *
      * The result of publishing each message is reported individually in the response. Because the batch request can result
      * in a combination of successful and unsuccessful actions, you should check for batch errors even when the call returns
-     * an HTTP status code of `200`.
+     * an HTTP status code of 200.
      *
      * The maximum allowed individual message size and the maximum total payload size (the sum of the individual lengths of
      * all of the batched messages) are both 256 KB (262,144 bytes).
      *
+     * ! The `PublishBatch` API can send up to 10 messages at a time. If you attempt to send more than 10 messages in one
+     * ! request, you will encounter a `TooManyEntriesInBatchRequest` exception. In such cases, split your messages into
+     * ! multiple requests, each containing no more than 10 messages.
+     *
      * Some actions take lists of parameters. These lists are specified using the `param.n` notation. Values of `n` are
-     * integers starting from 1. For example, a parameter list with two elements looks like this:
+     * integers starting from **1**. For example, a parameter list with two elements looks like this:
      *
-     * &AttributeName.1=first
+     * `&AttributeName.1=first`
      *
-     * &AttributeName.2=second
+     * `&AttributeName.2=second`
      *
      * If you send a batch message to a topic, Amazon SNS publishes the batch message to each endpoint that is subscribed to
      * the topic. The format of the batch message depends on the notification protocol for each subscribed endpoint.
      *
-     * When a `messageId` is returned, the batch message is saved and Amazon SNS immediately delivers the message to
+     * When a `messageId` is returned, the batch message is saved, and Amazon SNS immediately delivers the message to
      * subscribers.
      *
      * @see https://docs.aws.amazon.com/sns/latest/api/API_PublishBatch.html
@@ -503,9 +509,6 @@ class SnsClient extends AbstractApi
      * delivered to the endpoint, so that the endpoint owner can easily resubscribe to the topic if the `Unsubscribe`
      * request was unintended.
      *
-     * > Amazon SQS queue subscriptions require authentication for deletion. Only the owner of the subscription, or the
-     * > owner of the topic can unsubscribe using the required Amazon Web Services signature.
-     *
      * This action is throttled at 100 transactions per second (TPS).
      *
      * @see https://docs.aws.amazon.com/sns/latest/api/API_Unsubscribe.html
@@ -548,44 +551,6 @@ class SnsClient extends AbstractApi
         }
 
         switch ($region) {
-            case 'af-south-1':
-            case 'ap-east-1':
-            case 'ap-northeast-1':
-            case 'ap-northeast-2':
-            case 'ap-northeast-3':
-            case 'ap-south-1':
-            case 'ap-south-2':
-            case 'ap-southeast-1':
-            case 'ap-southeast-2':
-            case 'ap-southeast-3':
-            case 'ap-southeast-4':
-            case 'ap-southeast-5':
-            case 'ap-southeast-7':
-            case 'ca-central-1':
-            case 'ca-west-1':
-            case 'eu-central-1':
-            case 'eu-central-2':
-            case 'eu-north-1':
-            case 'eu-south-1':
-            case 'eu-south-2':
-            case 'eu-west-1':
-            case 'eu-west-2':
-            case 'eu-west-3':
-            case 'il-central-1':
-            case 'me-central-1':
-            case 'me-south-1':
-            case 'mx-central-1':
-            case 'sa-east-1':
-            case 'us-east-1':
-            case 'us-east-2':
-            case 'us-west-1':
-            case 'us-west-2':
-                return [
-                    'endpoint' => "https://sns.$region.amazonaws.com",
-                    'signRegion' => $region,
-                    'signService' => 'sns',
-                    'signVersions' => ['v4'],
-                ];
             case 'cn-north-1':
             case 'cn-northwest-1':
                 return [
@@ -630,7 +595,6 @@ class SnsClient extends AbstractApi
                     'signVersions' => ['v4'],
                 ];
             case 'fips-us-gov-east-1':
-            case 'us-gov-east-1':
                 return [
                     'endpoint' => 'https://sns.us-gov-east-1.amazonaws.com',
                     'signRegion' => 'us-gov-east-1',
@@ -638,7 +602,6 @@ class SnsClient extends AbstractApi
                     'signVersions' => ['v4'],
                 ];
             case 'fips-us-gov-west-1':
-            case 'us-gov-west-1':
                 return [
                     'endpoint' => 'https://sns.us-gov-west-1.amazonaws.com',
                     'signRegion' => 'us-gov-west-1',
@@ -677,6 +640,11 @@ class SnsClient extends AbstractApi
                 ];
         }
 
-        throw new UnsupportedRegion(\sprintf('The region "%s" is not supported by "Sns".', $region));
+        return [
+            'endpoint' => "https://sns.$region.amazonaws.com",
+            'signRegion' => $region,
+            'signService' => 'sns',
+            'signVersions' => ['v4'],
+        ];
     }
 }
